@@ -1,7 +1,7 @@
 import json
 import requests
 
-with open('janda/Base.json', 'r', encoding='utf-8') as f:
+with open('janda/base/Base.json', 'r', encoding='utf-8') as f:
     site = json.load(f)
     api_list = []
     for key, value in site.items():
